@@ -315,6 +315,8 @@ def mirror(src, dst, **kwargs):
             logger.warning(traceback.format_exc())
 
 
+file = r"C:\Users\Colemen\Desktop\DAZ DOWNLOADS\poses"
+get_files(file)
 # src = r"C:\Users\Colemen\Desktop\TEST_FOLDER\directoryMirrorTests\sourceDirectory"
 # dst = r"C:\Users\Colemen\Desktop\TEST_FOLDER\directoryMirrorTests\targetDirectory"
 # mirror(src, dst)
