@@ -38,12 +38,44 @@ SRC_PATH_SYNONYMS = ["source", "src", "src path", "source path", "file path"]
 
 
 def decompress(file_obj, compression="gzip"):
-    file_list = _gen_path_list(file_obj)
+    '''
+        Decompresses a file or list of files in place.
 
+        ----------
+
+        Arguments
+        -------------------------
+        `file_obj` {string|list}
+            A file path or list of file_paths to decompress.
+
+        [`compression`="gzip"] {string}
+            The type of compression to use.
+
+        Return {list}
+        ----------------------
+        A list of dictionaries [{file_path:"xx",content:"xx"},...]
+
+        An empty list if nothing is found.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 12-13-2021 12:08:44
+        `memberOf`: file
+        `version`: 1.0
+        `method_name`: decompress
+    '''
+    file_list = _gen_path_list(file_obj)
+    result_list = []
     if len(file_list) > 0:
         for file in file_list:
             if compression == "gzip":
-                _decompress_single_file_gzip(file)
+                data = {
+                    "file_path": file,
+                    "contents": _decompress_single_file_gzip(file)
+                }
+                result_list.append(data)
+    return result_list
 
 
 def compress(file_obj):
@@ -483,10 +515,11 @@ def get_data(file_path, **kwargs):
         `method_name`: get_data
     '''
 
-    file_path = strUtils.format.file_path(file_path)
     exclude = obj.get_kwarg(['exclude'], [], (list, str), **kwargs)
+    file_path = strUtils.format.file_path(file_path)
     if exists(file_path):
         # print(f"file exists: {file_path}")
+        # print(f"Getting data for file: {file_path}")
         try:
             file_data = {}
             file_data['file_name'] = os.path.basename(file_path)
@@ -509,8 +542,9 @@ def get_data(file_path, **kwargs):
             return file_data
         except FileNotFoundError as error:
             logger.warning(f"Error: {error}")
-            logger.warning(f"Failed to find the file: {file_path}")
             return None
+    else:
+        logger.warning(f"Failed to find the file: {file_path}")
 
 
 def get_modified_time(file_path):
